import json

from plain.views import View
from plain.views.csrf import CsrfExemptViewMixin

from .models import Pageview


class TrackView(CsrfExemptViewMixin, View):
    def post(self):
        if getattr(self.request, "impersonator", None):
            # Don't track page views if we're impersonating a user
            return 200

        data = json.loads(self.request.body)

        url = data["url"]
        title = data["title"]
        referrer = data["referrer"]
        timestamp = data["timestamp"]

        if user := getattr(self.request, "user", None):
            user_id = user.pk
        else:
            user_id = ""

        if session := getattr(self.request, "session", None):
            session_key = session.session_key or ""
        else:
            session_key = ""

        Pageview.objects.create(
            user_id=user_id,
            session_key=session_key,
            url=url,
            title=title,
            referrer=referrer,
            timestamp=timestamp,
        )

        return 201



import uuid

from plain import models


class Pageview(models.Model):
    uuid = models.UUIDField(default=uuid.uuid4, editable=False)

    url = models.URLField(max_length=255, db_index=True)
    timestamp = models.DateTimeField(db_index=True, auto_now_add=True)

    title = models.CharField(max_length=255, blank=True)
    referrer = models.URLField(max_length=255, blank=True)

    user_id = models.CharField(max_length=255, db_index=True, blank=True)
    session_key = models.CharField(max_length=255, db_index=True, blank=True)

    class Meta:
        ordering = ["-timestamp"]

    def __str__(self):
        return self.url



# Generated by Plain 0.14.1 on 2025-01-02 03:38

import uuid

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Pageview",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True)),
                ("uuid", models.UUIDField(default=uuid.uuid4, editable=False)),
                ("title", models.CharField(blank=True, max_length=255)),
                ("url", models.URLField(db_index=True, max_length=255)),
                ("referrer", models.URLField(blank=True, max_length=255)),
                ("timestamp", models.DateTimeField(auto_now_add=True, db_index=True)),
                (
                    "user_id",
                    models.CharField(blank=True, db_index=True, max_length=255),
                ),
                (
                    "session_key",
                    models.CharField(blank=True, db_index=True, max_length=255),
                ),
            ],
            options={
                "ordering": ["-timestamp"],
            },
        ),
    ]
